--- old/usr/src/cmd/prstat/prstat.c	Wed Apr  3 09:33:11 2013
+++ new/usr/src/cmd/prstat/prstat.c	Wed Apr  3 09:33:11 2013
@@ -20,6 +20,8 @@
  */
 
 /*
+ * Copyright (c) 2013 Gary Mills
+ *
  * Copyright 2009 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
  *
@@ -75,6 +77,10 @@
 #include <curses.h>
 #include <term.h>
 
+#define	LOGIN_WIDTH	8
+#define	ZONE_WIDTH	28
+#define	PROJECT_WIDTH	28
+
 #define	PSINFO_HEADER_PROC \
 "   PID USERNAME  SIZE   RSS STATE  PRI NICE      TIME  CPU PROCESS/NLWP       "
 #define	PSINFO_HEADER_PROC_LGRP \
@@ -108,8 +114,8 @@
 #define	PSINFO_LINE_LGRP \
 "%6d %-8s %5s %5s %-6s %3s  %3s %9s %3.3s%% %4d %-.16s/%d"
 #define	USAGE_LINE \
-"%6d %-8s %3.3s %3.3s %3.3s %3.3s %3.3s %3.3s %3.3s %3.3s %3.3s %3.3s %3.3s "\
-"%3.3s %-.12s/%d"
+"%6d %-8s %3.3s %3.3s %3.3s %3.3s %3.3s %3.3s %3.3s %3.3s %3.3s %3.3s "\
+"%3.3s %3.3s %-.12s/%d"
 #define	USER_LINE \
 "%6d %-8s %5.5s %5.5s   %3.3s%% %9s %3.3s%%"
 #define	TASK_LINE \
@@ -354,7 +360,7 @@
 	char vcx[4], icx[4], scl[4], sig[4];
 	char psize[6], prssize[6], pmem[6], pcpu[6], ptime[12];
 	char pstate[7], pnice[4], ppri[4];
-	char pname[LOGNAME_MAX+1];
+	char pname[LOGNAME_MAX_ILLUMOS+1];
 	char projname[PROJNAME_MAX+1];
 	char zonename[ZONENAME_MAX+1];
 	float cpu, mem;
@@ -446,16 +452,23 @@
 				mem = (100 * id->id_pctmem) / total_mem;
 			else
 				mem = id->id_pctmem;
-			if (list->l_type == LT_USERS)
-				pwd_getname(id->id_uid, pname, LOGNAME_MAX + 1,
-				    opts.o_outpmode & OPT_NORESOLVE);
-			else if (list->l_type == LT_ZONES)
+			if (list->l_type == LT_USERS) {
+				pwd_getname(id->id_uid, pname, sizeof (pname),
+				    opts.o_outpmode & OPT_NORESOLVE,
+				    opts.o_outpmode & OPT_TERMCAP,
+				    LOGIN_WIDTH);
+			} else if (list->l_type == LT_ZONES) {
 				getzonename(id->id_zoneid, zonename,
-				    ZONENAME_MAX);
-			else
+				    sizeof (zonename) - 1,
+				    opts.o_outpmode & OPT_TERMCAP,
+				    ZONE_WIDTH);
+			} else {
 				getprojname(id->id_projid, projname,
-				    PROJNAME_MAX,
-				    opts.o_outpmode & OPT_NORESOLVE);
+				    sizeof (projname) - 1,
+				    opts.o_outpmode & OPT_NORESOLVE,
+				    opts.o_outpmode & OPT_TERMCAP,
+				    PROJECT_WIDTH);
+			}
 			Format_size(psize, id->id_size, 6);
 			Format_size(prssize, id->id_rssize, 6);
 			Format_pct(pmem, mem, 4);
@@ -488,8 +501,10 @@
 			else
 				lwpid = lwp->li_info.pr_nlwp +
 				    lwp->li_info.pr_nzomb;
-			pwd_getname(lwp->li_info.pr_uid, pname, LOGNAME_MAX + 1,
-			    opts.o_outpmode & OPT_NORESOLVE);
+			pwd_getname(lwp->li_info.pr_uid, pname, sizeof (pname),
+			    opts.o_outpmode & OPT_NORESOLVE,
+			    opts.o_outpmode & OPT_TERMCAP,
+			    LOGIN_WIDTH);
 			if (opts.o_outpmode & OPT_PSINFO) {
 				Format_size(psize, lwp->li_info.pr_size, 6);
 				Format_size(prssize, lwp->li_info.pr_rssize, 6);
@@ -522,14 +537,15 @@
 				if (opts.o_outpmode & OPT_LGRP) {
 					(void) printf(PSINFO_LINE_LGRP,
 					    (int)lwp->li_info.pr_pid, pname,
-					    psize, prssize, pstate, ppri, pnice,
-					    ptime, pcpu,
+					    psize, prssize, pstate,
+					    ppri, pnice, ptime, pcpu,
 					    (int)lwp->li_info.pr_lwp.pr_lgrp,
 					    lwp->li_info.pr_fname, lwpid);
 				} else {
 					(void) printf(PSINFO_LINE,
 					    (int)lwp->li_info.pr_pid, pname,
-					    psize, prssize, pstate, ppri, pnice,
+					    psize, prssize,
+					    pstate, ppri, pnice,
 					    ptime, pcpu,
 					    lwp->li_info.pr_fname, lwpid);
 				}
